@@ -34,7 +34,6 @@ from pysight.gui.gui_helpers import verify_input
 from pysight.gui.config_parser import Config
 from pysight.nd_hist_generator.volume_gen import VolumeGenerator
 from pysight.binary_list_file_parser.binary_parser import (
-    BinaryDataParser,
     binary_parsing,
 )
 from pysight.read_lst import ReadData
@@ -90,6 +89,7 @@ def main_data_readout(config: MutableMapping[str, Any]) -> Optional[PySightOutpu
         bidir=config["advanced"]["bidir"],
         bidir_phase=config["advanced"]["phase"],
         image_soft=config["image"]["imaging_software"],
+        laser_freq=config["advanced"]["reprate"],
         lst_metadata=lst_metadata,
     )
 
@@ -203,13 +203,17 @@ def main_data_readout(config: MutableMapping[str, Any]) -> Optional[PySightOutpu
 
     final_movie.run()
     if "memory" in outputs.outputs:
+        if "flim" in outputs.outputs:
+            flim = final_movie.flim
+        else:
+            flim = None
         pysight_output = PySightOutput(
             photons=data_for_movie,
             summed_mem=final_movie.summed_mem,
             stack=final_movie.stack,
             channels=data_for_movie.index.levels[0],
             data_shape=outputs.data_shape,
-            flim=config["advanced"]["flim"],
+            flim=flim,
             config=config,
         )
         return pysight_output
